/*
 * Copyright 2006-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.consol.citrus.docker.client;

import com.github.dockerjava.core.DockerClientConfig;
import com.github.dockerjava.core.DockerClientImpl;
import com.github.dockerjava.jaxrs.DockerCmdExecFactoryImpl;

/**
 * Docker client uses Java docker client implementation for executing docker commands.
 *
 * @author Christoph Deppisch
 * @since 2.4
 */
public class DockerClient {

    /** Docker client configuration */
    private DockerClientConfig dockerClientConfig;

    /** Java docker client */
    private com.github.dockerjava.api.DockerClient dockerClient;

    /**
     * Default constructor.
     */
    public DockerClient() {
        super();
    }

    /**
     * Constructor using docker client instance.
     * @param dockerClient
     */
    public DockerClient(com.github.dockerjava.api.DockerClient dockerClient) {
        this();
        this.dockerClient = dockerClient;
    }

    /**
     * Creates new Docker client instance with configuration.
     * @return
     */
    private com.github.dockerjava.api.DockerClient createDockerClient() {
        return DockerClientImpl.getInstance(getDockerClientConfig())
                .withDockerCmdExecFactory(new DockerCmdExecFactoryImpl());
    }

    /**
     * Constructs or gets the docker client implementation.
     * @return
     */
    public com.github.dockerjava.api.DockerClient getDockerClient() {
        if(dockerClient == null) {
            dockerClient = createDockerClient();
        }

        return dockerClient;
    }

    /**
     * Gets the docker client configuration.
     * @return
     */
    public DockerClientConfig getDockerClientConfig() {
        if (dockerClientConfig == null) {
            dockerClientConfig = DockerClientConfig.createDefaultConfigBuilder().build();
        }

        return dockerClientConfig;
    }

    /**
     * Sets the docker client configuration.
     * @param dockerClientConfig
     */
    public void setDockerClientConfig(DockerClientConfig dockerClientConfig) {
        this.dockerClientConfig = dockerClientConfig;
    }
}
